# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2020 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

from enum import Enum

from clcommon.lib.cledition import is_cl_solo_edition

# CLWPOS Constants

# Keep it in alphabetical order

ALT_PHP_PREFIX = 'alt-php'
EA_PHP_PREFIX = 'ea-php'

ALLOWED_MODULES_JSON = 'modules_allowed.json'
ALT_PHP_REDIS_ENABLE_UTILITY = '/usr/share/cloudlinux/wpos/enable_redis_for_alt_php.py'
EA_PHP_REDIS_ENABLE_UTILITY = '/usr/sbin/enable_redis_for_ea_php'
INSTALL_CPANEL_CACHING_HOOKS_UTILITY = '/usr/share/cloudlinux/wpos/cpanel_hooks.py'
INSTALL_WPOS_HOOKS_UTILITY = '/usr/share/cloudlinux/wpos/wpos_hooks.py'

CAGEFS_ENTER_USER_BIN = '/sbin/cagefs_enter_user'
CLCONFIG_UTILITY = "/usr/sbin/cloudlinux-config"

DEFAULT_MAX_CACHE_MEMORY = 64
MINIMUM_MAX_CACHE_MEMORY = 16
MAXIMUM_MAX_CACHE_MEMORY = 16384  # 16 GB (in MB)

MINIMUM_SUPPORTED_PHP = 56

MONIROTING_SERVICE = 'clwpos_monitoring'
USER_WPOS_DIR = ".clwpos"
USER_CLWPOS_CONFIG = "clwpos_config.json"

PROJECT_NAME = "clwpos"
PUBLIC_OPTIONS = '/opt/clwpos/public_options.json'

# https://cl.sentry.cloudlinux.com/organizations/cloudlinux_os/issues/?project=12
SENTRY_DSN = 'https://9713d1296f804031b058b8f2d789d7ac:' \
             '8ddacae32d8246cf8b25cf826bf3fc0a@cl.sentry.cloudlinux.com/12'

CLWPOS_OPT_DIR = '/opt/clwpos'
CLWPOS_VAR_DIR = '/var/clwpos'
CLWPOS_UIDS_PATH = f'{CLWPOS_VAR_DIR}/uids'
CLWPOS_SOLO_PATH = f'{CLWPOS_VAR_DIR}/solo'
SCANNING_STATUS = f'{CLWPOS_VAR_DIR}/admin/status'
LAST_SCANNED_TS = f'{CLWPOS_VAR_DIR}/admin/last_scan.ts'
SCAN_CACHE = f'{CLWPOS_VAR_DIR}/admin/scan_cache.json'

CAGEFS_ENTER_UTIL = '/bin/cagefs_enter.proxied'
CAGEFSCTL = '/usr/sbin/cagefsctl'

WP_CLI_EXTENSIONS = ["-d extension=phar.so", "-d extension=json.so", "-d extension=mysqli.so"]
WPOS_DAEMON_SOCKET_FILE = "/opt/clwpos/wpos_redis_daemon.sock"
REDIS_SERVER_BIN_FILE = '/opt/alt/redis/bin/redis-server'

CL_DOC_USER_PLUGIN = 'https://user-docs.solo.cloudlinux.com/wpos-plugin' if is_cl_solo_edition(skip_jwt_check=True) \
    else 'https://user-docs.cloudlinux.com/wpos-plugin'


class RedisRequiredConstants(Enum):
    """
    Stores all needed redis consts for wp-config
    """
    WP_REDIS_SCHEME = 'unix'
    WP_REDIS_CLIENT = 'phpredis'
    WP_REDIS_SELECTIVE_FLUSH = 'true'
    # those const are custom, they`re rewritten in usage place
    WP_REDIS_PREFIX = 'CL-'
    WP_REDIS_PATH = None
