#!/opt/alt/python37/bin/python3 -bb
# -*- coding: utf-8 -*-

#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENCE.TXT

import subprocess
import sys

from clcommon.lib.cledition import is_cl_solo_edition
from clwpos.constants import INSTALL_CPANEL_CACHING_HOOKS_UTILITY
from clwpos.optimization_modules import is_module_allowed_for_user
from clwpos.utils import (
    is_wpos_supported,
    install_yum_universal_hook_alt_php,
    install_panel_hooks,
    uninstall_yum_universal_hook_alt_php,
    uninstall_panel_hooks,
)


def _install_hooks():
    if is_wpos_supported() and is_module_allowed_for_user():
        if not is_cl_solo_edition(skip_jwt_check=True):
            install_yum_universal_hook_alt_php()
        install_panel_hooks()
        subprocess.run([INSTALL_CPANEL_CACHING_HOOKS_UTILITY, '-i'], capture_output=True)


def _uninstall_hooks():
    if not is_cl_solo_edition(skip_jwt_check=True):
        uninstall_yum_universal_hook_alt_php()
    uninstall_panel_hooks()
    subprocess.run([INSTALL_CPANEL_CACHING_HOOKS_UTILITY, '-d'], capture_output=True)


def main():
    """
    Install or uninstall panel and yum/dnf universal hooks.
    """
    if '--install' in sys.argv:
        _install_hooks()
    elif '--uninstall' in sys.argv:
        _uninstall_hooks()


if __name__ == "__main__":
    main()
